@@ -1,4 +1,5 @@
 import uuid
+from urllib.parse import urlparse
 
 from httpdbg.initiator import get_initiator
 
@@ -7,11 +8,16 @@ class HTTPRecords:
     def __init__(self):
         self.id = str(uuid.uuid4())
         self.requests = {}
+        self.requests_already_loaded = 0
 
     def reset(self):
         self.id = str(uuid.uuid4())
         self.requests = {}
 
+    @property
+    def unread(self):
+        return self.requests_already_loaded < len(self.requests)
+
 
 class HTTPRecord:
     def __init__(self):
@@ -74,6 +80,19 @@ class HTTPRecord:
                 return value
         return ""
 
+    @property
+    def url(self):
+        return self.request.url
+
+    @property
+    def netloc(self):
+        url = urlparse(self.url)
+        return f"{url.scheme}://{url.netloc}"
+
+    @property
+    def urlext(self):
+        return self.url[len(self.netloc) :]
+
 
 def set_hook(mixtape):
     """Intercepts the HTTP requests"""
