@@ -5,7 +5,12 @@ import os
 from flask import Flask
 from flask_restful import Api
 
-from .api import Request, RequestContentDown, RequestContentUp, RequestList
+from httpdbg.webapp.api import (
+    Request,
+    RequestContentDown,
+    RequestContentUp,
+    RequestList,
+)
 
 app = Flask("httpdbgwebapp")
 app.static_folder = os.path.join(os.path.abspath(os.path.dirname(__file__)), "static")
@@ -22,6 +27,11 @@ def root():
     return app.send_static_file("index.htm")
 
 
+@app.route("/config")
+def config():
+    return app.send_static_file("config.htm")
+
+
 @app.after_request
 def add_header(response):
     response.cache_control.max_age = 0
